@@ -8,7 +8,9 @@ R <- function() knitr::include_graphics("Rlogo.png", dpi = 5000)
 ## ----eval=TRUE----------------------------------------------------------------
 library(hce)
 packageVersion("hce")
-citation("hce")
+
+## ----eval=FALSE, include=FALSE------------------------------------------------
+#  devtools::load_all()
 
 ## -----------------------------------------------------------------------------
 ls("package:hce")
@@ -46,6 +48,15 @@ HCE <- hce(GROUP = HCE1$GROUP, TRTP = HCE1$TRTP, AVAL0 = HCE1$AVAL0,
 class(HCE)
 head(HCE)
 
+## -----------------------------------------------------------------------------
+data(HCE1, package = "hce")
+class(HCE1)
+head(HCE1)
+
+## -----------------------------------------------------------------------------
+dat2 <- new_hce(HCE1)
+class(dat2)
+
 ## -----------------------------------------------------------------------------
 args("simHCE")
 
@@ -62,15 +73,6 @@ dat1 <- simHCE(n = 2500, n0 = 1500, TTE_A = Rates_A,
 class(dat1)
 head(dat1)
 
-## -----------------------------------------------------------------------------
-data(HCE1, package = "hce")
-class(HCE1)
-head(HCE1)
-
-## -----------------------------------------------------------------------------
-dat2 <- new_hce(HCE1)
-class(dat2)
-
 ## -----------------------------------------------------------------------------
 methods(class = "hce")
 
